package com.goldenwater.slaj.eutr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eutr.mapper.BisEutrEqAnswMapper;
import com.goldenwater.slaj.eutr.domain.BisEutrEqAnsw;
import com.goldenwater.slaj.eutr.service.IBisEutrEqAnswService;

@Service
public class BisEutrEqAnswServiceImpl implements IBisEutrEqAnswService {
    @Autowired
    private BisEutrEqAnswMapper bisEutrEqAnswMapper;

    @Override
    public BisEutrEqAnsw selectBisEutrEqAnswByGuid(String guid) {
        return bisEutrEqAnswMapper.selectBisEutrEqAnswByGuid(guid);
    }

    @Override
    public List<BisEutrEqAnsw> selectBisEutrEqAnswList(BisEutrEqAnsw bisEutrEqAnsw) {
        return bisEutrEqAnswMapper.selectBisEutrEqAnswList(bisEutrEqAnsw);
    }

    @Override
    public int insertBisEutrEqAnsw(BisEutrEqAnsw bisEutrEqAnsw) {
        return bisEutrEqAnswMapper.insertBisEutrEqAnsw(bisEutrEqAnsw);
    }

    @Override
    public int updateBisEutrEqAnsw(BisEutrEqAnsw bisEutrEqAnsw) {
        return bisEutrEqAnswMapper.updateBisEutrEqAnsw(bisEutrEqAnsw);
    }

    @Override
    public int deleteBisEutrEqAnswByGuid(String guid) {
        return bisEutrEqAnswMapper.deleteBisEutrEqAnswByGuid(guid);
    }

    @Override
    public int deleteBisEutrEqAnswByGuids(String[] guids) {
        return bisEutrEqAnswMapper.deleteBisEutrEqAnswByGuids(guids);
    }
}
